@@ -774,7 +774,8 @@ class Survey(Section):
             if parent and not parent.get("choice_filter"):
                 translation_key = survey_element.get_xpath() + ":label"
                 media_dict = survey_element.get("media")
-                _set_up_media_translations(media_dict, translation_key)
+                if isinstance(media_dict, dict):
+                    _set_up_media_translations(media_dict, translation_key)
 
     def itext(self):
         """
@@ -827,7 +828,7 @@ class Survey(Section):
                         itext_nodes.append(
                             node("value", value, toParseString=output_inserted)
                         )
-                    elif media_type == "image":
+                    elif media_type == "image" or media_type == "big-image":
                         if value != "-":
                             itext_nodes.append(
                                 node(
